@@ -23,7 +23,7 @@ from StringIO import StringIO
 from operator import itemgetter
 
 from logtools import (filterbots, geoip, logsample, logsample_weighted, 
-                      logparse, urlparse, logmerge, logplot, qps)
+                      logparse, urlparse, logmerge, logplot, qps, sumstat)
 from logtools.parsers import *
 from logtools import logtools_config, interpolate_config, AttrDict
 
@@ -50,6 +50,13 @@ class URLParseTestCase(unittest.TestCase):
             i+=1
         self.assertEquals(i, len(self.rows), \
                           "Number of rows output is not equal to input size")
+        
+    def testMultipleQueryParams(self):
+        url = "http://www.mydomain.com/my/path/myfile?myparam1=myval1&myparam2=myval2"
+        for row in urlparse(StringIO(url+"\n"), part='query', query_params='myparam1,myparam2'):
+            self.assertEquals(row[0], 'myval1', "Returned query param value was not as expected: %s" % \
+                          row)
+
     
 class ParsingTestCase(unittest.TestCase):
     def setUp(self):
@@ -156,7 +163,9 @@ class GeoIPTestCase(unittest.TestCase):
         
         self.fh = StringIO(
             "127.0.0.1 - USER_AGENT:'Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)' - ...\n" \
-            "255.255.255.255 - USER_AGENT:'Mozilla' - ...\n"
+            "255.255.255.255 - USER_AGENT:'Mozilla' - ...\n" \
+            "74.125.225.48 - USER_AGENT:'IE' - ...\n" \
+            "65.55.175.254 - USER_AGENT:'IE' - ...\n"
         )
 
     def testGeoIP(self):
@@ -168,7 +177,25 @@ class GeoIPTestCase(unittest.TestCase):
 
         output = [(geocode, ip, line) for geocode, ip, line in geoip(fh=self.fh, **self.options)]
         self.assertEquals(len(output), 2, "Output size was different than expected: %s" % str(len(output)))
-
+        
+    def testFilter(self):
+        """Test GeoIP filtering functionality"""        
+        try:
+            import GeoIP
+        except ImportError:
+            print >> sys.stderr, "GeoIP Python package not available - skipping geoip unittest."
+            return        
+        
+        # Check positive filter
+        self.options['filter'] = 'United States'
+        output = [(geocode, ip, line) for geocode, ip, line in geoip(fh=self.fh, **self.options)]
+        self.assertEquals(len(output), 2, "Output size was different than expected: %s" % str(len(output)))
+        
+        # Check negative filter
+        self.options['filter'] = 'India'
+        output = [(geocode, ip, line) for geocode, ip, line in geoip(fh=self.fh, **self.options)]
+        self.assertEquals(len(output), 0, "Output size was different than expected: %s" % str(len(output)))
+        
         
 class SamplingTestCase(unittest.TestCase):
     def setUp(self):
@@ -315,5 +342,24 @@ class PlotTestCase(unittest.TestCase):
         os.remove(tmp_fname)
     
 
+class SumstatTestCase(unittest.TestCase):
+    def setUp(self):
+        self.data = StringIO('\n'.join([
+            '500 val1',
+            '440 val2',
+            '320 val3',
+            '85 val4',
+            '13 val5'
+            ]))
+        self.avg = 271.6
+        self.N = 1358
+        self.M = 5
+        
+    def testSumstat(self):
+        stat = sumstat(fh=self.data, delimiter=' ', reverse=True)
+        self.assertEquals(stat['M'], self.M)
+        self.assertEquals(stat['N'], self.N)
+        self.assertEquals(stat['avg'], self.avg)
+        
 if __name__ == "__main__":
     unittest.main()
